<?xml version="1.0" encoding="UTF-8"?>

<!-- XMLVend Reference Server: Common Templates for Responses
    
    This file contains common / named templates which may be re-used to
    prevent tedious repetition of style rules when constructing response
    messages.
    
    This templates assumes that the input document
    contains baseVend information in the request, or a sub-type thereof (and not wrapped in
    something like SOAP).
    
    @version 0.1 (21 Feb 2006)
    @author K.P. Subramoney
    
-->

<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema">
    
    <!-- Declare Vend variables - These values may be updated-->
    
    <!-- Minimum Vend Amount -->
    <xsl:variable name="minVendAmt">0</xsl:variable>
    <!-- Debt recovery percentage -->
    <xsl:variable name="debt" select="10"/>
    <xsl:variable name="debtFact" select="$debt div 100"></xsl:variable>
    <!-- VAT percentage -->
    <xsl:variable name="VAT" select="14"/>
    <xsl:variable name="VATFact" select="1 + ($VAT div 100)"></xsl:variable>
    <!-- Tariff Rate (inclusive of VAT) -->
    <!--xsl:variable name="tariff" select="45.76 + (45.76 * ($VAT div 100))"></xsl:variable-->
	<xsl:variable name="tariff" select="1"></xsl:variable>
    <!-- FBE  in kWh-->
    <xsl:variable name="fbe" select="40"></xsl:variable>	
    <!-- Free Issue in rands -->
    <xsl:variable name="freeIssue" select="0"></xsl:variable>
    <!-- Fixed Charges Recovery in rands -->
    <xsl:variable name="daysLastPurchase" select="7"></xsl:variable>
	<xsl:variable name="fixedChargePerDay" select="2.5"></xsl:variable>
	
    <!--Updatable variables ends -->
    
        
    <!-- Inserts the common message attributes as per the BaseRequest/BaseResponse types.
    Requires the root element (request message) to be the current context node. -->
    <xsl:template name="baseVendResponseAttributes">
        
        <!-- Populate Meter Details based on the meter identifier -->
        <xsl:choose>
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterNumber' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./b0:idMethod/b0:meterIdentifier/@msno}"
                    sgc="100611" 
                    krn="1" 
                    ti="07">
                    <b0:meterType at="07" tt="02"/>
                </b0:meterDetail>
                <xsl:variable name="tempMSNO"><xsl:value-of select="./b0:idMethod/b0:meterIdentifier/@msno"/></xsl:variable>
            </xsl:when>
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterCard' )]">
                <!-- Track2Data with no date field -->
                <xsl:if test="string-length(./b0:idMethod/b0:meterIdentifier/b0:track2Data) = '34'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,7,11)}"
                        sgc="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,26,6)}" 
                        krn="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,34,1)}" 
                        ti="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,32,2)}">
                        <b0:meterType at="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,24,2)}" tt="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,22,2)}"/>
                    </b0:meterDetail>
                </xsl:if>  
                <!-- Track2Data with date field -->
                <xsl:if test="string-length(./b0:idMethod/b0:meterIdentifier/b0:track2Data) = '37'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,7,11)}"
                        sgc="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,29,6)}" 
                        krn="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,37,1)}" 
                        ti="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,35,2)}">
                        <b0:meterType at="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,27,2)}" tt="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,25,2)}"/>
                    </b0:meterDetail>
                </xsl:if>    
         </xsl:when>    
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterDetail' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./b0:idMethod/b0:meterIdentifier/@msno}"
                    sgc="{./b0:idMethod/b0:meterIdentifier/@sgc}"
                    krn="{./b0:idMethod/b0:meterIdentifier/@krn}" 
                    ti="{./b0:idMethod/b0:meterIdentifier/@ti}">
                    <b0:meterType at="{./b0:idMethod/b0:meterIdentifier/b0:meterType/@at}" tt="{./b0:idMethod/b0:meterIdentifier/b0:meterType/@tt}"/>
                </b0:meterDetail>
            </xsl:when>              
        </xsl:choose>
 
        
    </xsl:template>
    
    
    <!-- Default template, to match messages for which there is no other template.
        Sends a SOAP fault back to indicate that no message matched (UnsupportedUseCase?)-->
    <!-- TODO: Add SOAP fault -->
    <xsl:template match="/*" priority="-1">
        <error>
            <description>The server does not contain a template to process this request.</description>
            <likelyCause>Server misconfiguration (invalid XSLT templates).</likelyCause>
        </error>
    </xsl:template>
    
</xsl:stylesheet>
