<?xml version="1.0" encoding="UTF-8"?>
<?soap-response-to requestType="ClearTamperReq" namespace="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:m="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema"
    xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
    
    <!-- Import common templates -->
    <xsl:import href="../common/common.xsl"/>
    <xsl:import href="../common/baseVend.xsl"/>
    
    <!-- Match the root element of the request message -->
    <xsl:template match="/m:meterSpecificEngReq">
        
        <!-- Business Rule Check  -->
        <xsl:choose>
            <!-- check if client ID is type EANDeviceID only-->
            <xsl:when test="/*/b0:clientID[not(contains (string(@xsi:type), 'EANDeviceID' ))]">
                <soap:Fault>
                    <faultcode>soap:Server</faultcode>
                    <faultstring>A business rule fault was encountered on the server.</faultstring>
                    <detail>
                        <!-- XMLVend Fault Detail -->
                        <b0:xmlvendFaultResp>                    
                            <!-- Insert the Common request attributes -->
                            <xsl:call-template name="baseResponseAttributes"/>
                            
                            <b0:dispHeader>ONLINE VENDING ERROR</b0:dispHeader>
                            <b0:operatorMsg>ClientID = <xsl:value-of select="/*/b0:clientID/@xsi:type" />, Not valid. Verify the data provided and retry.</b0:operatorMsg>    
                            
                            <b0:fault xsi:type="b0:XMLVendSchemaEx">
                                <b0:desc>ClientID = <xsl:value-of select="/*/b0:clientID/@xsi:type" />, Not valid. Verify the data provided and retry.</b0:desc>                            
                            </b0:fault>
                            
                        </b0:xmlvendFaultResp>
                    </detail>
                </soap:Fault>                
            </xsl:when>
            <!-- check if <resource> type is Electricity -->
            <xsl:when test="./b0:resource[not(contains (string(@xsi:type), 'Electricity' ))]">
                <soap:Fault>
                    <faultcode>soap:Server</faultcode>
                    <faultstring>A business rule fault was encountered on the server.</faultstring>
                    <detail>
                        <!-- XMLVend Fault Detail -->
                        <b0:xmlvendFaultResp>                    
                            <!-- Insert the Common request attributes -->
                            <xsl:call-template name="baseResponseAttributes"/>
                            
                            <b0:dispHeader>ONLINE VENDING ERROR</b0:dispHeader>
                            <b0:operatorMsg>Resource = <xsl:value-of select="./b0:resource/@xsi:type" />, Not valid. Verify the data provided and retry.</b0:operatorMsg>    
                            <b0:custMsg>Resource = <xsl:value-of select="./b0:resource/@xsi:type" />, Not valid. Verify the data provided and retry.</b0:custMsg>    
                            <b0:fault xsi:type="b0:XMLVendSchemaEx">
                                <b0:desc>Resource = <xsl:value-of select="./b0:resource/@xsi:type" />, Not valid. Verify the data provided and retry.</b0:desc>                            
                            </b0:fault>
                            
                        </b0:xmlvendFaultResp>
                    </detail>
                </soap:Fault>                
            </xsl:when>    
            <xsl:otherwise>
        
                <m:meterSpecificEngResp xsi:type="m:ClearTamperResp">
                    
                    <!-- Insert the Common request attributes -->
                    <xsl:call-template name="baseResponseAttributes"/>
                    
                    <b0:dispHeader>METER SPECIFIC ENGINEERING</b0:dispHeader>
                    <b0:clientStatus>
                        <b0:availCredit value="1000" symbol="ZAR"/>
                    </b0:clientStatus>
                    <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890" />
                    <m:clearTamper>
                        <b0:desc>Clr tamper</b0:desc>
                        
                        <!-- Insert the BaseVend Meter request attributes -->
                        <xsl:call-template name="baseVendResponseAttributes"/>
                        
                        <b0:token xsi:type="b0:STS1Token">
                            <b0:stsCipher>00000000002281728512</b0:stsCipher>
                        </b0:token>
                    </m:clearTamper>
                </m:meterSpecificEngResp>
                
            </xsl:otherwise>
        </xsl:choose>
                
    </xsl:template>
    
</xsl:stylesheet>

