<?xml version="1.0" encoding="UTF-8"?>
<?soap-response-to requestType="EngKCTReq" namespace="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:m0="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema">
    
    <!-- Import common templates -->
    <xsl:import href="../common/common.xsl"/>
    
    <!-- Match the root element of the request message -->
    <xsl:template match="/m0:meterSpecificEngReq">
        
            <m0:meterSpecificEngResp  xsi:type="m0:EngKCTResp">
                
                <!-- Insert the Common request attributes -->
                <xsl:call-template name="baseResponseAttributes"/>
                
                <b0:dispHeader>KEY CHANGE</b0:dispHeader>
                <b0:clientStatus>
                <b0:availCredit value="1000" symbol="ZAR"/>
                </b0:clientStatus>
                <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890" />
                <m0:engKCToken>
                    <b0:desc>Eng Key Change</b0:desc>
                    
                    <!-- Insert MeterDetail -->
                    <xsl:call-template name="idMethodKCT"/>    
 
                    <b0:token xsi:type="b0:KCToken">
                        <b0:set1stMeterKey>
                            <b0:stsCipher>36893488147553322496</b0:stsCipher>
                        </b0:set1stMeterKey>
                        <b0:set2ndMeterKey>
                            <b0:stsCipher>18446744073843772416</b0:stsCipher>
                        </b0:set2ndMeterKey>
                    </b0:token>
                    <b0:kctData fromSGC="{./m0:kctData/@fromSGC}" fromKRN="{./m0:kctData/@fromKRN}" fromTI="{./m0:kctData/@fromTI}" toSGC="{./m0:kctData/@toSGC}" toKRN="{./m0:kctData/@toKRN}" toTI="{./m0:kctData/@toTI}"/>
                    <b0:pwrLmtToken>
                        <b0:desc>Power Limit Token</b0:desc>
                        
                        <!-- Insert MeterDetail -->
                        <xsl:call-template name="idMethodKCT"/>    
                        
                        <b0:token xsi:type="b0:STS1Token">
                            <b0:stsCipher>00000000001207974400</b0:stsCipher>
                        </b0:token>
                        <b0:pwrLmt value="13.8" siUnit="kW"/>   
                   </b0:pwrLmtToken>
                  </m0:engKCToken>
            </m0:meterSpecificEngResp>
        
    </xsl:template>
    
    <xsl:template name="idMethodKCT">
        <xsl:choose>
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterNumber' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./b0:idMethod/b0:meterIdentifier/@msno}"
                    sgc="{./m0:kctData/@toSGC}" 
                    krn="{./m0:kctData/@toKRN}" 
                    ti="{./m0:kctData/@toTI}">
                    <b0:meterType at="07" tt="02"/>
                </b0:meterDetail>
            </xsl:when>
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterCard' )]">
                <!-- Track2Data with no date field -->
                <xsl:if test="string-length(./b0:idMethod/b0:meterIdentifier/b0:track2Data) = '34'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,7,11)}"
                        sgc="{./m0:kctData/@toSGC}" 
                        krn="{./m0:kctData/@toKRN}" 
                        ti="{./m0:kctData/@toTI}">
                        <b0:meterType at="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,24,2)}" tt="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,22,2)}"/>
                    </b0:meterDetail>
                </xsl:if>  
                <!-- Track2Data with date field -->
                <xsl:if test="string-length(./b0:idMethod/b0:meterIdentifier/b0:track2Data) = '37'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,7,11)}"
                        sgc="{./m0:kctData/@toSGC}" 
                        krn="{./m0:kctData/@toKRN}" 
                        ti="{./m0:kctData/@toTI}">
                        <b0:meterType at="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,27,2)}" tt="{substring(./b0:idMethod/b0:meterIdentifier/b0:track2Data,25,2)}"/>
                    </b0:meterDetail>
                </xsl:if>    
            </xsl:when>    
            <xsl:when test="./b0:idMethod/b0:meterIdentifier[contains (string(@xsi:type), 'MeterDetail' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./b0:idMethod/b0:meterIdentifier/@msno}"
                    sgc="{./m0:kctData/@toSGC}" 
                    krn="{./m0:kctData/@toKRN}" 
                    ti="{./m0:kctData/@toTI}">
                    <b0:meterType at="{./b0:idMethod/b0:meterIdentifier/b0:meterType/@at}" tt="{./b0:idMethod/b0:meterIdentifier/b0:meterType/@tt}"/>
                </b0:meterDetail>
            </xsl:when>     
            <xsl:otherwise>
                <b0:error>No meter details</b0:error>
            </xsl:otherwise>                    
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
