<?xml version="1.0" encoding="UTF-8"?>
<?soap-response-to requestType="UpdateMeterKeyReq" namespace="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:m0="http://www.nrs.eskom.co.za/xmlvend/meter/2.1/schema"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema">
    
    <!-- Import common templates -->
    <xsl:import href="../common/common.xsl"/>
    
    <!-- Match the root element of the request message -->
    <xsl:template match="/m0:updateMeterKeyReq">
        
                    <m0:updateMeterKeyResp>
                            
                        <!-- Insert the Common request attributes -->
                        <xsl:call-template name="baseResponseAttributes"/>
                            
                        <b0:dispHeader>Update Meter Key</b0:dispHeader>
                        <b0:operatorMsg>Advise customer to enter both tokens.</b0:operatorMsg>
                        <b0:clientStatus>
                            <b0:availCredit value="1000" symbol="ZAR"/>
                        </b0:clientStatus>
                        <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890" />
                        <m0:updateMeterKey>
                            <b0:desc>Update Meter Key</b0:desc>

                            <!-- Insert MeterDetail -->
                            <xsl:call-template name="idMethodKCT"/>                              
                            
                            <b0:token xsi:type="b0:KCToken">
                                <b0:set1stMeterKey>
                                    <b0:stsCipher>36893488147553322496</b0:stsCipher>
                                </b0:set1stMeterKey>
                                <b0:set2ndMeterKey>
                                    <b0:stsCipher>18446744073843772416</b0:stsCipher>
                                </b0:set2ndMeterKey>
                            </b0:token>
                            
                            <!-- Populate KCTData based on the meter identifier -->
                            <xsl:choose>
                                <xsl:when test="./m0:idMethod[contains (string(@xsi:type), 'MeterCard' )]">
                                    <!-- Track2Data with no date field -->
                                    <xsl:if test="string-length(./m0:idMethod/b0:track2Data) = '34'">                                        
                                        <b0:kctData fromSGC="{substring(./m0:idMethod/b0:track2Data,26,6)}" 
                                            fromKRN="{substring(./m0:idMethod/b0:track2Data,34,1)}" 
                                            fromTI="{substring(./m0:idMethod/b0:track2Data,32,2)}"
                                            toSGC="100405" toKRN="1" toTI="52"/>
                                     </xsl:if>
                                    <!-- Track2Data with date field -->
                                    <xsl:if test="string-length(./m0:idMethod/b0:track2Data) = '37'">
                                        <b0:kctData fromSGC="{substring(./m0:idMethod/b0:track2Data,29,6)}" 
                                            fromKRN="{substring(./m0:idMethod/b0:track2Data,37,1)}" 
                                            fromTI="{substring(./m0:idMethod/b0:track2Data,35,2)}"
                                            toSGC="100405" toKRN="1" toTI="52"/>
                                    </xsl:if>    
                                </xsl:when>    
                                <xsl:when test="./m0:idMethod[contains (string(@xsi:type), 'MeterDetail' )]">
                                    <b0:kctData fromSGC="{./m0:idMethod/@sgc}" 
                                        fromKRN="{./m0:idMethod/@krn}" 
                                        fromTI="{./m0:idMethod/@ti}"
                                        toSGC="100405" toKRN="1" toTI="52"/>
                                </xsl:when>     
                                <xsl:otherwise>
                                    <m0:error>No meter details</m0:error>
                                </xsl:otherwise>                    
                            </xsl:choose>
                            
                            
                          
                            <b0:pwrLmtToken>
                                <b0:desc>Power Limit Token</b0:desc>
                                
                                <!-- Insert MeterDetail -->
                                <xsl:call-template name="idMethodKCT"/>        
                                
                                <b0:token xsi:type="b0:STS1Token">
                                    <b0:stsCipher>00000000001207974400</b0:stsCipher>
                                </b0:token>
                                <b0:pwrLmt value="13.8" siUnit="kW"/>
                            </b0:pwrLmtToken>
                        </m0:updateMeterKey>
                    </m0:updateMeterKeyResp>

    </xsl:template>
    
    <xsl:template name="idMethodKCT">
        
        <!-- Populate Meter Details based on the meter identifier -->
        <xsl:choose>
            <xsl:when test="./m0:idMethod[contains (string(@xsi:type), 'MeterNumber' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./m0:idMethod/@msno}"
                    sgc="100405" 
                    krn="1" 
                    ti="52">
                    <b0:meterType at="07" tt="02"/>
                </b0:meterDetail>
            </xsl:when>
            <xsl:when test="./m0:idMethod[contains (string(@xsi:type), 'MeterCard' )]">
                <!-- Track2Data with no date field -->
                <xsl:if test="string-length(./m0:idMethod/b0:track2Data) = '34'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./m0:idMethod/b0:track2Data,7,11)}"
                        sgc="100405" 
                        krn="1" 
                        ti="52">
                        <b0:meterType at="{substring(./m0:idMethod/b0:track2Data,24,2)}" tt="{substring(./m0:idMethod/b0:track2Data,22,2)}"/>
                    </b0:meterDetail>
                </xsl:if>
                <!-- Track2Data with date field -->
                <xsl:if test="string-length(./m0:idMethod/b0:track2Data) = '37'">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{substring(./m0:idMethod/b0:track2Data,7,11)}"
                        sgc="100405" 
                        krn="1" 
                        ti="52">
                        <b0:meterType at="{substring(./m0:idMethod/b0:track2Data,27,2)}" tt="{substring(./m0:idMethod/b0:track2Data,25,2)}"/>
                    </b0:meterDetail>                            
                </xsl:if>    
            </xsl:when>    
            <xsl:when test="./m0:idMethod[contains (string(@xsi:type), 'MeterDetail' )]">
                <b0:meterDetail xsi:type="b0:MeterDetail" 
                    msno="{./m0:idMethod/@msno}"
                    sgc="100405" 
                    krn="1" 
                    ti="52">
                    <b0:meterType at="{./m0:idMethod/b0:meterType/@at}" tt="{./m0:idMethod/b0:meterType/@tt}"/>
                </b0:meterDetail>
            </xsl:when>     
            <xsl:otherwise>
                <m0:error>No meter details</m0:error>
            </xsl:otherwise>                    
        </xsl:choose>
        
    </xsl:template>
    
</xsl:stylesheet>
