<?xml version="1.0" encoding="UTF-8"?>
<?soap-response-to requestType="ReprintReq" namespace="http://www.nrs.eskom.co.za/xmlvend/revenue/2.1/schema"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:r0="http://www.nrs.eskom.co.za/xmlvend/revenue/2.1/schema"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema">
    
    <!-- Import common templates -->
    <xsl:import href="../common/common.xsl"/>
    
    
    
    <!-- Match the root element of the request message -->
    <xsl:template match="/r0:reprintReq">
        
                <r0:reprintResp>
                    
                    <!-- Insert the Common request attributes -->
                    <xsl:call-template name="baseResponseAttributes"/>
                    
                    <b0:dispHeader>TAX INVOICE (copy)</b0:dispHeader>
                      <r0:reprint xsi:type="r0:CreditVendResp">
                      <b0:clientID xsi:type="b0:EANDeviceID" ean="1234567890123"/>
                      <b0:serverID xsi:type="b0:EANDeviceID" ean="3210987654321"/>
                      <b0:terminalID xsi:type="b0:GenericDeviceID" id="1"/>
                      <b0:reqMsgID dateTime="20051021083333" uniqueNumber="78"/>
                      <b0:respDateTime>2005-10-21T14:55:56.041Z</b0:respDateTime>
                      <b0:dispHeader>CREDIT VEND - TAX INVOICE</b0:dispHeader>
                      <b0:clientStatus>
                          <b0:availCredit  value="2000" symbol="ZAR"/>
                          <b0:batchStatus banking="open" sales="open" shift="open"/>
                      </b0:clientStatus>
                      <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890"/> 
                      <b0:vendor name="Foo Corner Store" address="12 Foo Road, Foo Town, 9999" />
                          
                          <!-- Populate customer details -->
                          <xsl:apply-templates select="r0:idMethod/b0:custIdentifier"/>  
                          
                          <r0:creditVendReceipt receiptNo="1234567890">
                          <r0:transactions>
                              <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                  <r0:amt value="45" symbol="ZAR"/>
                                  <r0:tax xsi:type="b0:VAT" rate="14">
                                      <b0:amt  value="5.53" symbol="ZAR"/>
                                  </r0:tax>
                                  <r0:creditTokenIssue xsi:type="b0:SaleCredTokenIssue">
                                      <b0:desc>Normal Sale</b0:desc>
                                      
                                      <!--If Cust ID then poulate default Meter Detail -->
                                      <xsl:if test="contains(string(./r0:idMethod/@xsi:type), 'b0:CustIDMethod' )">
                                          <b0:meterDetail xsi:type="b0:MeterDetail" 
                                              msno="06686069342"
                                              sgc="100611" 
                                              krn="1" 
                                              ti="07">
                                              <b0:meterType at="07" tt="02"/>
                                          </b0:meterDetail>               
                                      </xsl:if>
                                      
                                      <!-- Populate meter details -->
                                      <xsl:apply-templates select="r0:idMethod/b0:meterIdentifier"/>  
                                      
                                      <b0:token xsi:type="b0:STS1Token">
                                          <b0:stsCipher>56493153725450313471</b0:stsCipher>
                                      </b0:token>
                                      
                                      <b0:units value="86.26" siUnit="kWh" />
                                      <b0:resource xsi:type="b0:Electricity"/>
                                  </r0:creditTokenIssue>
                                  <r0:tariff>
                                      <b0:name>HomeLight 1</b0:name>
                                      <b0:desc>60 A: 45,76c + VAT = 52,17c/kWh</b0:desc>
                                  </r0:tariff>
                              </r0:tx>
							  <!-- Reprint Debt Recovery-->
                              <r0:tx xsi:type="r0:DebtRecoveryTx" receiptNo="4444444444">
                                  <r0:amt value="5" symbol="ZAR"/>
                                  <r0:tax xsi:type="b0:VAT" rate="14">
                                      <b0:amt  value="0" symbol="ZAR"/>
                                  </r0:tax>
                                  <r0:accDesc>Conventional debt </r0:accDesc>
                                  
                                  <!-- Populate the Acc No from request or a default value -->
                                  <xsl:choose>
                                      <xsl:when test="contains(string(./r0:idMethod/b0:custIdentifier/@xsi:type), 'CustAccountNo')">
                                          <r0:accNo><xsl:value-of select="./r0:idMethod/b0:custIdentifier/@accNo"/></r0:accNo>    
                                      </xsl:when>
                                      <xsl:otherwise>
                                          <r0:accNo>12345678</r0:accNo>
                                      </xsl:otherwise>
                                  </xsl:choose>
                                  
                                  <r0:tariff>
                                      <b0:name>Debt Recovery1</b0:name>
                                      <b0:desc>10% of requested transaction </b0:desc>
                                  </r0:tariff>
                                  <r0:balance  value="1000" symbol="ZAR"/>
                              </r0:tx>
                              <r0:lessRound  value="0" symbol="ZAR"/>
                              <r0:tenderAmt  value="100" symbol="ZAR"/>
                              <r0:change  value="50" symbol="ZAR"/>
                          
						  <!-- Reprint Fixed Charge Tx -->
								<r0:tx xsi:type="r0:ServiceChrgTx" receiptNo="8888888888">
										<r0:amt value="15" symbol="ZAR"/>
										<r0:tax xsi:type="b0:VAT" rate="14">
										   <b0:amt  value="0" symbol="ZAR"/>
										</r0:tax>
										<r0:accDesc>Fixed Charges</r0:accDesc>
											
						<!-- Populate the Acc No from request or a default value -->
											
									 <xsl:choose>
									 <xsl:when test="contains(string(./r0:idMethod/b0:custIdentifier/@xsi:type), 'CustAccountNo')">
									 <r0:accNo><xsl:value-of select="./r0:idMethod/b0:custIdentifier/@accNo"/></r0:accNo>    
									 </xsl:when>
									 <xsl:otherwise>
                                          <r0:accNo>12345678</r0:accNo>
                                     </xsl:otherwise>
									 </xsl:choose>
								  
									<r0:tariff>
                                      <b0:name>NetworkCapacityChrg</b0:name>
                                      <b0:desc>3 of 7 days @ 29/07/2016</b0:desc>
                                    </r0:tariff>
                                         <r0:balance  value="1000" symbol="ZAR"/>
                                </r0:tx>
									<r0:lessRound  value="0" symbol="ZAR"/>
									<r0:tenderAmt  value="100" symbol="ZAR"/>
									<r0:change  value="50" symbol="ZAR"/>
						</r0:transactions>									
                      </r0:creditVendReceipt>
                  </r0:reprint>
                    <r0:reprint xsi:type="r0:CreditVendResp">
                        <b0:clientID xsi:type="b0:EANDeviceID" ean="1234567890123"/>
                        <b0:serverID xsi:type="b0:EANDeviceID" ean="3210987654321"/>
                        <b0:terminalID xsi:type="b0:GenericDeviceID" id="1"/>
                        <b0:reqMsgID dateTime="20051021083333" uniqueNumber="78"/>
                        <b0:respDateTime>2005-10-21T14:55:56.041Z</b0:respDateTime>
                        <b0:dispHeader>CREDIT VEND - TAX INVOICE</b0:dispHeader>
                        <b0:clientStatus>
                            <b0:availCredit  value="2000" symbol="ZAR"/>
                            <b0:batchStatus banking="open" sales="open" shift="open"/>
                        </b0:clientStatus>
                        <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890"/> 
                        <b0:vendor name="Foo Corner Store" address="12 Foo Road, Foo Town, 9999" />
                        
                        <!-- Populate customer details -->
                        <xsl:apply-templates select="r0:idMethod/b0:custIdentifier"/>  
                        
                        <r0:creditVendReceipt receiptNo="1234567890">
                            <r0:transactions>
                                <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                    <r0:amt value="45" symbol="ZAR"/>
                                    <r0:tax xsi:type="b0:VAT" rate="14">
                                        <b0:amt  value="5.53" symbol="ZAR"/>
                                    </r0:tax>
                                    <r0:creditTokenIssue xsi:type="b0:SaleCredTokenIssue">
                                        <b0:desc>Normal Sale</b0:desc>
                                        
                                        <!--If Cust ID then poulate default Meter Detail -->
                                        <xsl:if test="contains(string(./r0:idMethod/@xsi:type), 'b0:CustIDMethod' )">
                                            <b0:meterDetail xsi:type="b0:MeterDetail" 
                                                msno="06686069342"
                                                sgc="100611" 
                                                krn="1" 
                                                ti="07">
                                                <b0:meterType at="07" tt="02"/>
                                            </b0:meterDetail>               
                                        </xsl:if>
                                                                               
                                        <!-- Populate meter details -->
                                        <xsl:apply-templates select="r0:idMethod/b0:meterIdentifier"/>  
                                        
                                        <b0:token xsi:type="b0:STS1Token">
                                            <b0:stsCipher>56493153725450313471</b0:stsCipher>
                                        </b0:token>
                                        
                                        <b0:units value="86.26" siUnit="kWh" />
                                        <b0:resource xsi:type="b0:Electricity"/>
                                    </r0:creditTokenIssue>
                                    <r0:tariff>
                                        <b0:name>HomeLight 1</b0:name>
                                        <b0:desc>60 A: 45,76c + VAT = 52,17c/kWh</b0:desc>
                                    </r0:tariff>
                                </r0:tx>
                                <r0:tx xsi:type="r0:DebtRecoveryTx" receiptNo="4444444334">
                                    <r0:amt value="5" symbol="ZAR"/>
                                    <r0:tax xsi:type="b0:VAT" rate="14">
                                        <b0:amt  value="0" symbol="ZAR"/>
                                    </r0:tax>
                                    <r0:accDesc>Conventional debt </r0:accDesc>
                                    
                                    <!-- Populate the Acc No from request or a default value -->
                                    <xsl:choose>
                                        <xsl:when test="contains(string(./r0:idMethod/b0:custIdentifier/@xsi:type), 'CustAccountNo')">
                                            <r0:accNo><xsl:value-of select="./r0:idMethod/b0:custIdentifier/@accNo"/></r0:accNo>    
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <r0:accNo>12345678</r0:accNo>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    
                                    <r0:tariff>
                                                <b0:name>Debt Recovery1</b0:name>
                                                <b0:desc>10% of requested transaction </b0:desc>
                                    </r0:tariff>
                                            <r0:balance  value="1000" symbol="ZAR"/>
                                </r0:tx>
                                <r0:lessRound  value="0" symbol="ZAR"/>
                                <r0:tenderAmt  value="100" symbol="ZAR"/>
                                <r0:change  value="50" symbol="ZAR"/>
                            </r0:transactions>
                        </r0:creditVendReceipt>
                    </r0:reprint>
                    <r0:reprint xsi:type="r0:PayAccResp">
                        <b0:clientID xsi:type="b0:EANDeviceID" ean="1234567890123"  />
                        <b0:serverID xsi:type="b0:EANDeviceID" ean="3210987654321" />
                        <b0:terminalID xsi:type="b0:GenericDeviceID" id="1" />    
                        <b0:reqMsgID dateTime="20051028083333" uniqueNumber="3"/>
                        <b0:respDateTime>2005-10-27T14:55:56.041Z</b0:respDateTime>
                        <b0:dispHeader>ACCOUNT PAYMENT</b0:dispHeader>
                        <b0:clientStatus>
                            <b0:availCredit  value="2000" symbol="ZAR"/>
                            <b0:batchStatus banking="open" sales="open" shift="open"/>
                        </b0:clientStatus>
                        <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890"/> 
                        <b0:vendor name="Foo Corner Store" address="12 Foo Road, Foo Town, 9999" />
                        
                        <!-- Populate customer details -->
                        <xsl:apply-templates select="r0:idMethod/b0:custIdentifier"/>  
                        
                        <r0:payAccReceipt receiptNo="1234567">
                            <r0:transactions>
                                <r0:tx xsi:type="r0:DebtRecoveryTx">
                                    <r0:amt value="54" symbol="ZAR"/>
                                    <r0:tax xsi:type="b0:VAT" rate="14">
                                        <b0:amt value="6.63" symbol="ZAR"/>
                                    </r0:tax>    
                                    <r0:accDesc>Conventional debt recovery</r0:accDesc>
                                    
                                    <!-- Populate the Acc No from request or a default value -->
                                    <xsl:choose>
                                        <xsl:when test="contains(string(./r0:idMethod/b0:custIdentifier/@xsi:type), 'CustAccountNo')">
                                            <r0:accNo><xsl:value-of select="./r0:idMethod/b0:custIdentifier/@accNo"/></r0:accNo>    
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <r0:accNo>12345678</r0:accNo>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                                                                                          
                                    <r0:balance value="3800.00" symbol="ZAR"/>
                                </r0:tx>
                            </r0:transactions>
                        </r0:payAccReceipt>
                    </r0:reprint>
             </r0:reprintResp>    
 
    </xsl:template>
    
    <!-- Customer Details Template -->
    <xsl:template match="r0:idMethod/b0:custIdentifier">
               
        <xsl:choose>
            <!-- Cust ID by Name -->
            <xsl:when test="contains (string(./@xsi:type), 'CustName' )">
                    <b0:custVendDetail name="{./b0:name} Bar" address="10 Foo Lane, Johannesburg, 1700" accNo="12345678901" daysLastPurchase="5" />
            </xsl:when>
            <!-- Cust ID by Address -->
            <xsl:when test="contains (string(./@xsi:type), 'CustAddress' )">
                    <b0:custVendDetail name="Foo Bar" address="{./b0:address}" accNo="12345678901" daysLastPurchase="4" />
            </xsl:when>
            <!-- Cust ID by AccNo -->
            <xsl:when test="contains (string(./@xsi:type), 'CustAccountNo' )">
                    <b0:custVendDetail name="Foo Bar" address="11 Foo Lane, Johannesburg, 1700" accNo="{./@accNo}" daysLastPurchase="2" />
            </xsl:when>
            <!-- Cust ID by IDNo -->                
            <xsl:when test="contains (string(./@xsi:type), 'CustIDNumber' )">
                    <b0:custVendDetail name="Foo Bar" address="11 Foo Lane, Johannesburg, 1700" accNo="0987654321" daysLastPurchase="1" />
             </xsl:when>
        </xsl:choose>        
    </xsl:template>
    
    <!-- Template - Populate Meter Details based on the meter identifier -->
    <xsl:template match="r0:idMethod/b0:meterIdentifier">
        <xsl:choose>
            <xsl:when test="contains (string(./@xsi:type), 'MeterNumber' )">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{./@msno}"
                        sgc="100611" 
                        krn="1" 
                        ti="07">
                        <b0:meterType at="07" tt="02"/>
                    </b0:meterDetail>
            </xsl:when>
            <xsl:when test="contains (string(./@xsi:type), 'MeterCard' )">
                <!-- Track2Data with no date field -->
                <xsl:if test="string-length(./b0:track2Data) = '34'">
                        <b0:meterDetail xsi:type="b0:MeterDetail" 
                            msno="{substring(./b0:track2Data,7,11)}"
                            sgc="{substring(./b0:track2Data,26,6)}" 
                            krn="{substring(./b0:track2Data,34,1)}" 
                            ti="{substring(./b0:track2Data,32,2)}">
                            <b0:meterType at="{substring(./b0:track2Data,24,2)}" tt="{substring(./b0:track2Data,22,2)}"/>
                        </b0:meterDetail>
                </xsl:if>  
                <!-- Track2Data with date field -->
                <xsl:if test="string-length(./b0:track2Data) = '37'">
                        <b0:meterDetail xsi:type="b0:MeterDetail" 
                            msno="{substring(./b0:track2Data,7,11)}"
                            sgc="{substring(./b0:track2Data,29,6)}" 
                            krn="{substring(./b0:track2Data,37,1)}" 
                            ti="{substring(./b0:track2Data,35,2)}">
                            <b0:meterType at="{substring(./b0:track2Data,27,2)}" tt="{substring(./b0:track2Data,25,2)}"/>
                        </b0:meterDetail>
                </xsl:if>    
            </xsl:when>
            <!-- All meter details -->
            <xsl:when test="contains (string(./@xsi:type), 'MeterDetail' )">
                    <b0:meterDetail xsi:type="b0:MeterDetail" 
                        msno="{./@msno}"
                        sgc="{./@sgc}"
                        krn="{./@krn}" 
                        ti="{./@ti}">
                        <b0:meterType at="{./b0:meterType/@at}" tt="{./b0:meterType/@tt}"/>
                    </b0:meterDetail>
            </xsl:when>
        </xsl:choose>   
        
    </xsl:template>
    
</xsl:stylesheet>
