<?xml version="1.0" encoding="UTF-8"?>
<?soap-response-to requestType="TrialCreditVendReq" namespace="http://www.nrs.eskom.co.za/xmlvend/revenue/2.1/schema"?>
<xsl:stylesheet 
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:r0="http://www.nrs.eskom.co.za/xmlvend/revenue/2.1/schema"
    xmlns:b0="http://www.nrs.eskom.co.za/xmlvend/base/2.1/schema"
    xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
    
    <!-- Import common templates -->
    <xsl:import href="../common/common.xsl"/>
    <xsl:import href="../common/baseVend.xsl"/>
    
    <!-- Match the root element of the request message -->
    <xsl:template match="/r0:trialCreditVendReq">
        
        <!-- Calculate the transaction amounts-->
		<xsl:variable name="fixedChargeAmt" select="$daysLastPurchase * $fixedChargePerDay"/>
        <xsl:variable name="txDebtAmt" select="number(./r0:purchaseValue/r0:amt/@value) * $debtFact"/>
        <xsl:variable name="txAmt" select="./r0:purchaseValue/r0:amt/@value - ($txDebtAmt) - ($fixedChargeAmt)"/>
        
        <!-- Business Rule Check  -->
        <xsl:choose>
            
            <!-- Insert Business Rule minVendAmt check   -->
            
            <xsl:when test="$minVendAmt > $txAmt"> 
                
                <soap:Fault>
                    <faultcode>soap:Server</faultcode>
                    <faultstring>A business rule fault was encountered on the server.</faultstring>
                    <detail>
                        <!-- XMLVend Fault Detail -->
                        <b0:xmlvendFaultResp>                    
                            <!-- Insert the Common request attributes -->
                            <xsl:call-template name="baseResponseAttributes"/>
                            
                            <b0:dispHeader>ONLINE VENDING ERROR</b0:dispHeader>
                            <b0:operatorMsg>The vend amout requested (<xsl:value-of select="$txAmt"/>) is below the <xsl:value-of select="$minVendAmt"/>.</b0:operatorMsg>    
                            
                            <b0:fault xsi:type="b0:BusinessRuleEx">
                                <b0:desc>The vend amount requested (<xsl:value-of select="$txAmt"/>) is below the <xsl:value-of select="$minVendAmt"/>.</b0:desc>                            
                            </b0:fault>
                            
                        </b0:xmlvendFaultResp>
                    </detail>
                </soap:Fault>
            </xsl:when>
            
            <!-- Normal Response, busines rule checks passed -->
            <xsl:otherwise>   
                <r0:trialCreditVendResp>
                    
                    <!-- Insert the Common request attributes -->
                    <xsl:call-template name="baseResponseAttributes"/>
                    
                    <b0:dispHeader>CREDIT VEND - TAX INVOICE</b0:dispHeader>
                    <b0:clientStatus>
                        <b0:availCredit  value="2000" symbol="ZAR"/>
                        <b0:batchStatus banking="open" sales="open" shift="open"/>
                    </b0:clientStatus>
                    <b0:utility name="Eskom" address="Foo Road" taxRef="1234567890"/> 
                    <b0:vendor name="Foo Corner Store" address="12 Foo Road, Foo Town, 9999" />
                    <b0:custVendDetail name="Mr XMLVend" address="10 XMLVend Avenue, XMLVendVille, 8888" contactNo="(011)6789089" accNo="0987654321" locRef="erf34567" daysLastPurchase="41"/>
                    <r0:creditVendReceipt receiptNo="1234567890">
                        <xsl:choose>
                            <!-- Purchase Value is Currency -->
                            <xsl:when test="./r0:purchaseValue[contains (string(@xsi:type), 'PurchaseValueCurrency' )]">
                                <r0:transactions>
                                    
                                    <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                        <r0:amt value="{$txAmt}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                        <r0:tax xsi:type="b0:VAT" rate="{$VAT}">
                                            <b0:amt  value="{format-number(($txAmt - ($txAmt div $VATFact)),'###0.00')}" symbol="ZAR"/>
                                        </r0:tax>
                                        <r0:creditTokenIssue xsi:type="b0:SaleCredTokenIssue">
                                            <b0:desc>Normal Sale</b0:desc>
                                            
                                            <!-- Insert the BaseVend Meter request attributes -->
                                            <xsl:call-template name="baseVendResponseAttributes"/>    
                                            
                                            <b0:token xsi:type="b0:STS1Token">
                                                <b0:stsCipher>00000000000000000000</b0:stsCipher>
                                            </b0:token>
                                            <b0:units value="{format-number(($txAmt * 100) div $tariff,'###0.00')}" siUnit="kWh" />
                                            <b0:resource xsi:type="b0:Electricity"/>
                                        </r0:creditTokenIssue>
                                        <r0:tariff>
                                            <b0:name>HomeLight 1 (60A)</b0:name>
                                            <b0:desc><xsl:value-of select="format-number($tariff,'###0.00')"/> c/kWh</b0:desc>
                                        </r0:tariff>
                                    </r0:tx>
                                    
                                    <!-- If FBE value > 0 then create a FBE token and transaction -->
                                    <xsl:if test="$fbe > 0">
                                        <!--FBE Tx value set to R0-->
                                        <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                            <r0:amt value="0" symbol="ZAR"/>
                                            <r0:creditTokenIssue xsi:type="b0:FBECredTokenIssue">
                                                <b0:desc>FBE Token</b0:desc>
                                                
                                                <!-- Insert the BaseVend Meter request attributes -->
                                                <xsl:call-template name="baseVendResponseAttributes"/>    
                                                
                                                <b0:token xsi:type="b0:STS1Token">
                                                    <b0:stsCipher>00000000000000000000</b0:stsCipher>
                                                </b0:token>
                                                <b0:units value="{$fbe}" siUnit="kWh" />
                                                <b0:resource xsi:type="b0:Electricity"/>
                                            </r0:creditTokenIssue>
                                        </r0:tx>
                                    </xsl:if>    
                                    
                                    <!-- Only create a Debt Tx if the debt percent > 0, No VAT is applied toDebt  -->
                                    <xsl:if test="$debt > 0">
                                        <r0:tx xsi:type="r0:DebtRecoveryTx" receiptNo="4444444444">
                                            <r0:amt value="{$txDebtAmt}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                            <r0:tax xsi:type="b0:VAT" rate="{$VAT}">
                                                <b0:amt  value="0" symbol="ZAR"/>
                                            </r0:tax>
                                            <r0:accDesc>Conventional debt </r0:accDesc>
                                            <r0:accNo>0987654321</r0:accNo>
                                            <r0:tariff>
                                                <b0:name>Debt Recovery1</b0:name>
                                                <b0:desc><xsl:value-of select="$debt"/>% of requested transaction </b0:desc>
                                            </r0:tariff>
                                            <r0:balance  value="1000" symbol="ZAR"/>
                                        </r0:tx>
                                    </xsl:if>    
                                    <r0:lessRound  value="0" symbol="ZAR"/>
                                    <!-- Only create a Fixed Charge Tx if the daysLastPurchase > 0, No VAT is applied -->
                                    <xsl:if test="$daysLastPurchase > 0">
                                        <r0:tx xsi:type="r0:ServiceChrgTx" receiptNo="8888888888">
                                            <r0:amt value="{$fixedChargeAmt}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                            <r0:tax xsi:type="b0:VAT" rate="{$VAT}">
                                                <b0:amt  value="0" symbol="ZAR"/>
                                            </r0:tax>
                                            <r0:accDesc>Fixed Charges</r0:accDesc>
                                            <r0:accNo>0987654321</r0:accNo>
                                            <r0:tariff>
                                                <b0:name>NetworkCapacityChrg <xsl:value-of select="$daysLastPurchase"/> days: R <xsl:value-of select="$daysLastPurchase * $fixedChargePerDay"/></b0:name>  
                                                <b0:desc><xsl:value-of select="$daysLastPurchase"/> of 50 days @ <xsl:value-of select="$Date"/> </b0:desc>
                                            </r0:tariff>
										</r0:tx>
									</xsl:if>
									<!-- Calculate Change -->
                                    <xsl:choose>
                                        <xsl:when test="./r0:payType[b0:tenderAmt]">
                                            <r0:tenderAmt  value="{./r0:payType/b0:tenderAmt/@value}" symbol="{./r0:payType/b0:tenderAmt/@symbol}"/>
                                            <r0:change  value="{./r0:payType/b0:tenderAmt/@value - ./r0:purchaseValue/r0:amt/@value}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                        </xsl:when>
                                        <xsl:when test="./r0:payType[b0:cheqAmt ]">
                                            <r0:tenderAmt  value="{./r0:payType/b0:cheqAmt/@value}" symbol="{./r0:payType/b0:cheqAmt/@symbol}"/>
                                            <r0:change  value="{./r0:payType/b0:cheqAmt/@value - ./r0:purchaseValue/r0:amt/@value}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                        </xsl:when>
                                        <xsl:when test="./r0:payType[b0:cardAmt]">
                                            <r0:tenderAmt  value="{./r0:payType/b0:cardAmt/@value}" symbol="{./r0:payType/b0:cardAmt/@symbol}"/>
                                            <r0:change  value="{./r0:payType/b0:cardAmt/@value - ./r0:purchaseValue/r0:amt/@value}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <r0:tenderAmt  value="{./r0:purchaseValue/r0:amt/@value}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                            <r0:change  value="{./r0:purchaseValue/r0:amt/@value - ./r0:purchaseValue/r0:amt/@value}" symbol="{./r0:purchaseValue/r0:amt/@symbol}"/>
                                        </xsl:otherwise>
                                    </xsl:choose>                                          
                                </r0:transactions>
                            </xsl:when>
                            <!-- Purchase Value is in Units 
                                Note: No debt is recovered???
                            -->
                            <xsl:when test="./r0:purchaseValue[contains (string(@xsi:type), 'PurchaseValueUnits' )]">
                                <r0:transactions>
                                    
                                    <!-- Caculate the transaction amounts-->
                                    <xsl:variable name="txAmt2" select="((./r0:purchaseValue/r0:units/@value * $tariff) div 100)"/>
                                    
                                    <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                        <r0:amt value="{format-number($txAmt2,'###0.00')}" symbol="ZAR"/>
                                        <r0:tax xsi:type="b0:VAT" rate="{$VAT}">
                                            <b0:amt  value="{format-number(($txAmt2 - ($txAmt2 div $VATFact)),'###0.00')}" symbol="ZAR"/>
                                        </r0:tax>
                                        <r0:creditTokenIssue xsi:type="b0:SaleCredTokenIssue">
                                            <b0:desc>Normal Sale</b0:desc>
                                            
                                            <!-- Insert the BaseVend Meter request attributes -->
                                            <xsl:call-template name="baseVendResponseAttributes"/>    
                                            
                                            <b0:token xsi:type="b0:STS1Token">
                                                <b0:stsCipher>00000000000000000000</b0:stsCipher>
                                            </b0:token>
                                            <b0:units value="{format-number(($txAmt2 * 100) div $tariff,'###0.00')}" siUnit="kWh" />
                                            <b0:resource xsi:type="b0:Electricity"/>
                                        </r0:creditTokenIssue>
                                        <r0:tariff>
                                            <b0:name>HomeLight 1 (60A)</b0:name>
                                            <b0:desc><xsl:value-of select="format-number($tariff,'###0.00')"/> c/kWh</b0:desc>
                                        </r0:tariff>
                                    </r0:tx>
                                    
                                    <!-- If FBE value > 0 then create a FBE token and transaction -->
                                    <xsl:if test="$fbe > 0">
                                        <!--FBE Tx value set to R0-->
                                        <r0:tx xsi:type="r0:CreditVendTx" receiptNo="0987564321">
                                            <r0:amt value="0" symbol="ZAR"/>
                                            <r0:creditTokenIssue xsi:type="b0:FBECredTokenIssue">
                                                <b0:desc>FBE Token</b0:desc>
                                                
                                                <!-- Insert the BaseVend Meter request attributes -->
                                                <xsl:call-template name="baseVendResponseAttributes"/>    
                                                
                                                <b0:token xsi:type="b0:STS1Token">
                                                    <b0:stsCipher>00000000000000000000</b0:stsCipher>
                                                </b0:token>
                                                <b0:units value="{$fbe}" siUnit="kWh" />
                                                <b0:resource xsi:type="b0:Electricity"/>
                                            </r0:creditTokenIssue>
                                        </r0:tx>
                                    </xsl:if>    
                                </r0:transactions> 
                                
                            </xsl:when>
                        </xsl:choose>                        
                    </r0:creditVendReceipt>
                </r0:trialCreditVendResp>
            </xsl:otherwise>                                  
        </xsl:choose>
        
    </xsl:template>
    
</xsl:stylesheet>
